/** 
* tin-refresh-jquery1.0.0 
* By wushain
* https://github.com/zx1988826/tin-refresh-jquery/
 */
(function($) {
    "use strict";

    $.fn.transitionEnd = function(callback) {
        var events = ['webkitTransitionEnd', 'transitionend', 'oTransitionEnd', 'MSTransitionEnd', 'msTransitionEnd'],
            i, dom = this;

        function fireCallBack(e) {
            /*jshint validthis:true */
            if (e.target !== this) return;
            callback.call(this, e);
            for (i = 0; i < events.length; i++) {
                dom.off(events[i], fireCallBack);
            }
        }
        if (callback) {
            for (i = 0; i < events.length; i++) {
                dom.on(events[i], fireCallBack);
            }
        }
        return this;
    };

    $.support = (function() {
        var support = {
            touch: !!(('ontouchstart' in window) || window.DocumentTouch && document instanceof window.DocumentTouch)
        };
        return support;
    })();

    $.touchEvents = {
        start: $.support.touch ? 'touchstart' : 'mousedown',
        move: $.support.touch ? 'touchmove' : 'mousemove',
        end: $.support.touch ? 'touchend' : 'mouseup'
    };

    $.getTouchPosition = function(e) {
        e = e.originalEvent || e; //jquery wrap the originevent
        if (e.type === 'touchstart' || e.type === 'touchmove' || e.type === 'touchend') {
            return {
                x: e.targetTouches[0].pageX,
                y: e.targetTouches[0].pageY
            };
        } else {
            return {
                x: e.pageX,
                y: e.pageY
            };
        }
    };

    $.fn.scrollHeight = function() {
        return this[0].scrollHeight;
    };

    $.fn.transform = function(transform) {
        for (var i = 0; i < this.length; i++) {
            var elStyle = this[i].style;
            elStyle.webkitTransform = elStyle.MsTransform = elStyle.msTransform = elStyle.MozTransform = elStyle.OTransform = elStyle.transform = transform;
        }
        return this;
    };
    $.fn.transition = function(duration) {
        if (typeof duration !== 'string') {
            duration = duration + 'ms';
        }
        for (var i = 0; i < this.length; i++) {
            var elStyle = this[i].style;
            elStyle.webkitTransitionDuration = elStyle.MsTransitionDuration = elStyle.msTransitionDuration = elStyle.MozTransitionDuration = elStyle.OTransitionDuration = elStyle.transitionDuration = duration;
        }
        return this;
    };

    $.getTranslate = function(el, axis) {
        var matrix, curTransform, curStyle, transformMatrix;

        // automatic axis detection
        if (typeof axis === 'undefined') {
            axis = 'x';
        }

        curStyle = window.getComputedStyle(el, null);
        if (window.WebKitCSSMatrix) {
            // Some old versions of Webkit choke when 'none' is passed; pass
            // empty string instead in this case
            transformMatrix = new WebKitCSSMatrix(curStyle.webkitTransform === 'none' ? '' : curStyle.webkitTransform);
        } else {
            transformMatrix = curStyle.MozTransform || curStyle.OTransform || curStyle.MsTransform || curStyle.msTransform || curStyle.transform || curStyle.getPropertyValue('transform').replace('translate(', 'matrix(1, 0, 0, 1,');
            matrix = transformMatrix.toString().split(',');
        }

        if (axis === 'x') {
            //Latest Chrome and webkits Fix
            if (window.WebKitCSSMatrix)
                curTransform = transformMatrix.m41;
            //Crazy IE10 Matrix
            else if (matrix.length === 16)
                curTransform = parseFloat(matrix[12]);
            //Normal Browsers
            else
                curTransform = parseFloat(matrix[4]);
        }
        if (axis === 'y') {
            //Latest Chrome and webkits Fix
            if (window.WebKitCSSMatrix)
                curTransform = transformMatrix.m42;
            //Crazy IE10 Matrix
            else if (matrix.length === 16)
                curTransform = parseFloat(matrix[13]);
            //Normal Browsers
            else
                curTransform = parseFloat(matrix[5]);
        }

        return curTransform || 0;
    };
    $.requestAnimationFrame = function(callback) {
        if (window.requestAnimationFrame) return window.requestAnimationFrame(callback);
        else if (window.webkitRequestAnimationFrame) return window.webkitRequestAnimationFrame(callback);
        else if (window.mozRequestAnimationFrame) return window.mozRequestAnimationFrame(callback);
        else {
            return window.setTimeout(callback, 1000 / 60);
        }
    };

    $.cancelAnimationFrame = function(id) {
        if (window.cancelAnimationFrame) return window.cancelAnimationFrame(id);
        else if (window.webkitCancelAnimationFrame) return window.webkitCancelAnimationFrame(id);
        else if (window.mozCancelAnimationFrame) return window.mozCancelAnimationFrame(id);
        else {
            return window.clearTimeout(id);
        }
    };

    $.fn.join = function(arg) {
        return this.toArray().join(arg);
    }
})($);

/**
 * [drop_down_refresh]
 * @说明  jquery下拉刷新插件
 */
+ function($) {
    "use strict";

    var DDR = function(el) {
        var _self = this;
        _self.ddr = $(el);
        _self.distance = 60;
        _self.listening();
    }

    DDR.prototype.start = function(el) {
        if (this.ddr.hasClass('refreshing')) return;
        this.startPosition = $.getTouchPosition(el);
        this.diffPositionY = 0;
    };

    DDR.prototype.move = function(el) {
        var _self = this;
        if (_self.ddr.hasClass('refreshing')) return;
        if (!_self.startPosition) return;
        if (_self.ddr.scrollTop() > 0) return;
        var startPositionY = _self.startPosition.y;
        var movePositionY = $.getTouchPosition(el).y;
        _self.diffPositionY = movePositionY - startPositionY;
        if (_self.diffPositionY < 0) return;
        _self.ddr.addClass('tin-ddr-moving');
        el.preventDefault();
        el.stopPropagation();
        _self.diffPositionY = Math.pow(_self.diffPositionY, 0.8);
        _self.ddr.css("transform", "translate3d(0, " + _self.diffPositionY + "px, 0)");
        if (_self.diffPositionY < _self.distance) {
            _self.ddr.addClass('tin-ddr-downing').removeClass('tin-ddr-uping');
        } else {
            _self.ddr.addClass('tin-ddr-uping').removeClass('tin-ddr-downing');
        }
    };

    DDR.prototype.end = function(el) {
        var _self = this;
        if (_self.ddr.hasClass('refreshing') || _self.diffPositionY <= 0) return;
        _self.start = false;
        _self.ddr.removeClass('tin-ddr-moving').removeClass('tin-ddr-downing').removeClass('tin-ddr-uping');
        _self.ddr.css("transform", "");
        if (Math.abs(_self.diffPositionY) > _self.distance) {
            _self.ddr.addClass("refreshing");
            _self.ddr.trigger('tin-ddr-callback');
            _self.diffPositionY = 0;
        }
    };

    DDR.prototype.listening = function() {
        var _self = this;
        var el = _self.ddr;
        el.on($.touchEvents.start, $.proxy(_self.start, _self));
        el.on($.touchEvents.move, $.proxy(_self.move, _self));
        el.on($.touchEvents.end, $.proxy(_self.end, _self));
    };

    $.fn.dropDownRefresh = function() {
        var _self = this;
        if (_self.hasClass('tin-ddr')) {
            return _self.each(function() {
                new DDR(_self)
            });
        } else {
            return false;
        }
    };

    $.fn.dropDownRefreshOver = function() {
        this.removeClass("refreshing");
    }
}($);

/**
 * [infinite]
 * @说明  jquery上拉加载插件
 */
+ function($) {
    "use strict";

    var infinite = function(el, distance) {
        this.jqElement = $(el);
        this.distance = distance || 0;
        this.listening();
    };

    infinite.prototype.scroll = function() {
        var _self = this;
        $(window).scroll(function() {
            var diffDistance = _self.jqElement.scrollHeight() - (_self.jqElement.scrollTop() + $(window).height());
            if (_self.jqElement.hasClass("tin-infinite-loading")) {
                return false;
            } else {
                if (diffDistance <= _self.distance) {
                    _self.jqElement.trigger('tin-infinite');
                    _self.jqElement.addClass("tin-infinite-loading");
                }
            }
        });
    };

    infinite.prototype.listening = function() {
        var _self = this;
        _self.scroll();
    };

    $.fn.pullOnLoading = function() {
        var _self = this;
        if (_self.hasClass("tin-infinite")) {
            return _self.each(function() {
                new infinite(_self, 20);
            });
        } else {
            return false;
        }
    };

    $.fn.pullOnLoadingDone = function() {
        this.removeClass("tin-infinite-loading");
    }


}($);
